@@ -32,6 +32,7 @@ class PhononWidget;
 class PixmapViewer;
 class PlacesItemModel;
 class QPixmap;
+class QDialogButtonBox;
 class QString;
 class QLabel;
 class QScrollArea;
@@ -40,13 +41,9 @@ namespace KIO {
   class PreviewJob;
 }
 
-#ifndef HAVE_BALOO
-class KFileMetaDataWidget;
-#else
 namespace Baloo {
     class FileMetaDataWidget;
 }
-#endif
 
 /**
  * @brief Manages the widgets that display the meta information
@@ -79,8 +76,21 @@ public:
      */
     void refreshPreview();
 
+    /**
+     * Switch the metadatawidget into configuration mode
+     */
+    void configureShownProperties();
+
+    /*
+     * Set the auto play media mode for the file previewed
+     * Eventually starting media playback when turning it on
+     * But not stopping it when turning it off
+     */
+    void setPreviewAutoPlay(bool autoPlay);
+
 signals:
     void urlActivated( const QUrl& url );
+    void configurationFinished();
 
 public slots:
     /**
@@ -138,12 +148,10 @@ private:
     PixmapViewer* m_preview;
     PhononWidget* m_phononWidget;
     QLabel* m_nameLabel;
-#ifndef HAVE_BALOO
-    KFileMetaDataWidget* m_metaDataWidget;
-#else
     Baloo::FileMetaDataWidget* m_metaDataWidget;
-#endif
     QScrollArea* m_metaDataArea;
+    QLabel* m_configureLabel;
+    QDialogButtonBox* m_configureButtons;
 
     PlacesItemModel* m_placesItemModel;
 };
